# Install git

Git is required to work with BlocksNet code or to use the library in your own project.

## Download and install

1. Install git:
   ```bash
   sudo apt install -y git
   ```
2. Check the installation:
   ```bash
   git --version
   ```
   Expected output:
   ```
   git version 2.42.0
   ```

## Clone the repository

If you work with your own repository, clone it instead:

```bash
git clone https://github.com/aimclub/blocksnet ~/projects/blocksnet
```

Where:

- `https://github.com/aimclub/blocksnet` - the repository to clone.
- `~/projects/blocksnet` - path to the directory where repository files will be located. Change it according to your preferences.

Then proceed to the cloned repository directory:

```bash
cd ~/projects/blocksnet
```
